@@ -61,19 +61,21 @@ namespace hidden
 /** @ingroup hidden
  *  @brief Specialization of the Traits class for the Array2DLowerTriangular class.
  **/
-template<class _Type>
-struct Traits< Array2DLowerTriangular<_Type> >
+template<class Type_>
+struct Traits< Array2DLowerTriangular<Type_> >
 {  private:
     class Void {};
   public:
-    typedef _Type                         Type;
-    typedef Array2DPoint<_Type>           Row;
-    typedef Array2DVector<_Type>          Col;
-    typedef Array2DPoint<_Type>           SubRow;
-    typedef Array2DVector<_Type>          SubCol;
-    typedef Array2DLowerTriangular<_Type> SubArray;
+    typedef Array2DPoint<Type_>           Row;
+    typedef Array2DVector<Type_>          Col;
+    typedef Array2DPoint<Type_>           SubRow;
+    typedef Array2DVector<Type_>          SubCol;
+    typedef Array2DLowerTriangular<Type_> SubArray;
     typedef Void                          SubVector;
 
+    typedef Type_                Type;
+    typedef typename RemoveConst<Type_>::Type const& ReturnType;
+
    enum
    {
      structure_ = Arrays::lower_triangular_,
@@ -99,16 +101,23 @@ struct Traits< Array2DLowerTriangular<_Type> >
   * matrix is defined for @em i=j and the lower part of the matrix is
   * the set of index [i,j], with i<j.
  **/
-template<class Type >
-class Array2DLowerTriangular : public IArray2D< Array2DLowerTriangular<Type> >
+template<class Type_ >
+class Array2DLowerTriangular : public IArray2D< Array2DLowerTriangular<Type_> >
 {
   public:
-    typedef typename hidden::Traits<Array2DLowerTriangular<Type> >::Row Row;
-    typedef typename hidden::Traits<Array2DLowerTriangular<Type> >::Col Col;
-    typedef typename hidden::Traits<Array2DLowerTriangular<Type> >::SubRow SubRow;
-    typedef typename hidden::Traits<Array2DLowerTriangular<Type> >::SubCol SubCol;
-    typedef typename hidden::Traits<Array2DLowerTriangular<Type> >::SubVector SubVector;
-    typedef typename hidden::Traits<Array2DLowerTriangular<Type> >::SubArray SubArray;
+    /** Type for the Interface Class.*/
+    typedef IArray2D< Array2DLowerTriangular<Type_> > Base;
+    typedef ArrayBase < Array2DLowerTriangular<Type_> > LowBase;
+
+    typedef typename hidden::Traits<Array2DLowerTriangular<Type_> >::Row Row;
+    typedef typename hidden::Traits<Array2DLowerTriangular<Type_> >::Col Col;
+    typedef typename hidden::Traits<Array2DLowerTriangular<Type_> >::SubRow SubRow;
+    typedef typename hidden::Traits<Array2DLowerTriangular<Type_> >::SubCol SubCol;
+    typedef typename hidden::Traits<Array2DLowerTriangular<Type_> >::SubVector SubVector;
+    typedef typename hidden::Traits<Array2DLowerTriangular<Type_> >::SubArray SubArray;
+
+    typedef typename hidden::Traits<Array2DLowerTriangular<Type_> >::Type Type;
+    typedef typename hidden::Traits<Array2DLowerTriangular<Type_> >::ReturnType ReturnType;
 
    enum
    {
@@ -118,9 +127,6 @@ class Array2DLowerTriangular : public IArray2D< Array2DLowerTriangular<Type> >
      sizeCols_  = UnknownSize,
      storage_ = Arrays::dense_ // always dense
    };
-    /** Type for the Interface Class.*/
-    typedef IArray2D< Array2DLowerTriangular<Type> > Base;
-    typedef ArrayBase < Array2DLowerTriangular<Type> > LowBase;
 
     /** Default constructor */
     Array2DLowerTriangular() : Base() {}
