@@ -59,19 +59,21 @@ namespace hidden
 /** @ingroup hidden
  *  @brief Specialization of the Traits class for the Array2DUpperTriangular class.
  **/
-template<typename _Type>
-struct Traits< Array2DUpperTriangular<_Type> >
+template<typename Type_>
+struct Traits< Array2DUpperTriangular<Type_> >
 {
   private:
     class Void {};
   public:
-    typedef _Type                         Type;
-    typedef Array2DPoint<_Type>           Row;
-    typedef Array2DVector<_Type>          Col;
-    typedef Array2DPoint<_Type>           SubRow;
-    typedef Array2DVector<_Type>          SubCol;
-    typedef Array2DUpperTriangular<_Type> SubArray;
+    typedef Array2DPoint<Type_>           Row;
+    typedef Array2DVector<Type_>          Col;
+    typedef Array2DPoint<Type_>           SubRow;
+    typedef Array2DVector<Type_>          SubCol;
+    typedef Array2DUpperTriangular<Type_> SubArray;
     typedef Void                          SubVector;
+
+    typedef Type_                Type;
+    typedef typename RemoveConst<Type_>::Type const& ReturnType;
     enum
     {
       structure_ = Arrays::upper_triangular_,
@@ -92,16 +94,23 @@ struct Traits< Array2DUpperTriangular<_Type> >
   * The container can be set upper triangular again using the method
   * IArray2D::update().
   **/
-template<typename Type>
-class Array2DUpperTriangular : public IArray2D< Array2DUpperTriangular<Type> >
+template<typename Type_>
+class Array2DUpperTriangular : public IArray2D< Array2DUpperTriangular<Type_> >
 {
   public:
-    typedef typename hidden::Traits<Array2DUpperTriangular<Type> >::Row Row;
-    typedef typename hidden::Traits<Array2DUpperTriangular<Type> >::Col Col;
-    typedef typename hidden::Traits<Array2DUpperTriangular<Type> >::SubRow SubRow;
-    typedef typename hidden::Traits<Array2DUpperTriangular<Type> >::SubCol SubCol;
-    typedef typename hidden::Traits<Array2DUpperTriangular<Type> >::SubVector SubVector;
-    typedef typename hidden::Traits<Array2DUpperTriangular<Type> >::SubArray SubArray;
+    /** Type for the Interface Class.                                 */
+    typedef IArray2D< Array2DUpperTriangular<Type_> > Base;
+    typedef ArrayBase < Array2DUpperTriangular<Type_> > LowBase;
+
+    typedef typename hidden::Traits<Array2DUpperTriangular<Type_> >::Row Row;
+    typedef typename hidden::Traits<Array2DUpperTriangular<Type_> >::Col Col;
+    typedef typename hidden::Traits<Array2DUpperTriangular<Type_> >::SubRow SubRow;
+    typedef typename hidden::Traits<Array2DUpperTriangular<Type_> >::SubCol SubCol;
+    typedef typename hidden::Traits<Array2DUpperTriangular<Type_> >::SubVector SubVector;
+    typedef typename hidden::Traits<Array2DUpperTriangular<Type_> >::SubArray SubArray;
+
+    typedef typename hidden::Traits<Array2DUpperTriangular<Type_> >::Type Type;
+    typedef typename hidden::Traits<Array2DUpperTriangular<Type_> >::ReturnType ReturnType;
 
     enum
     {
@@ -111,10 +120,6 @@ class Array2DUpperTriangular : public IArray2D< Array2DUpperTriangular<Type> >
       sizeCols_  = UnknownSize,
       storage_ = Arrays::dense_ // always dense
     };
-    /** Type for the Interface Class.                                 */
-    typedef IArray2D< Array2DUpperTriangular<Type> > Base;
-    typedef ArrayBase < Array2DUpperTriangular<Type> > LowBase;
-
     /** Default constructor */
     Array2DUpperTriangular() : Base() {}
     /** constructor with specified ranges
