@@ -74,6 +74,13 @@ template<typename Lhs, typename Rhs, typename Result>
 struct MultCoefImpl
 {
   typedef typename Result::Type Type;
+  enum
+  {
+    sizeRows_  = Result::sizeRows_,
+    sizeCols_  = Result::sizeCols_,
+    orient_    = Result::orient_,
+    storage_   = Result::storage_
+  };
   /** dot product. general by general*/
   static void dot( Lhs const& lhs, Rhs const& rhs, Result& res, int iRow, int jCol)
   {
@@ -84,7 +91,7 @@ struct MultCoefImpl
   }
   /** dot product. general by vector */
   static void dot( Lhs const& lhs, ITContainer<Rhs, Arrays::vector_> const& rhs
-                 , ICAllocator<Result>& res, int iRow)
+                 , ICAllocator<Result, sizeRows_, sizeCols_>& res, int iRow)
   {
     res.elt(iRow) = Type(0);
     Range const dotRange = Range::inf(lhs.rangeColsInRow(iRow), rhs.range());
@@ -93,7 +100,7 @@ struct MultCoefImpl
   }
   /** dot product. general by vector */
   static void dot( ITContainer<Lhs, Arrays::point_> const& lhs
-                 , Rhs const& rhs, ICAllocator<Result>& res, int jCol)
+                 , Rhs const& rhs, ICAllocator<Result, sizeRows_, sizeCols_>& res, int jCol)
   {
     res.elt(jCol) = Type(0);
     Range const dotRange = Range::inf(rhs.rangeRowsInCol(jCol), lhs.range());
