@@ -132,6 +132,9 @@ enum strategyType
 enum exceptions
 {
   randomInitFail_,
+  randomParamInitFail_,
+  randomClassInitFail_,
+  randomFuzzyInitFail_,
   estimFail_,
   initializeStepFail_,
   mStepFail_,
@@ -168,6 +171,7 @@ enum MixtureClass
   Gamma_,
   Gaussian_,
   Categorical_,
+  Poisson_,
   unknown_mixture_class_
 };
 
@@ -194,6 +198,9 @@ enum Mixture
   Gaussian_s_,
   Categorical_pjk_,
   Categorical_pk_,
+  Poisson_ljk_,
+  Poisson_lk_,
+  Poisson_ljlk_,
   unknown_mixture_
 };
 
@@ -226,6 +233,9 @@ MixtureClass mixtureToMixtureClass( Mixture const& type);
  * <tr> <td> "Gaussian_s"      </td></tr>
  * <tr> <td> "Categorical_pjk" </td></tr>
  * <tr> <td> "Categorical_pk"  </td></tr>
+ * <tr> <td> "Poisson_ljk"     </td></tr>
+ * <tr> <td> "Poisson_lk"      </td></tr>
+ * <tr> <td> "Poisson_ljlk"    </td></tr>
  * </table>
  *  @param type the String we want to convert
  *  @return the Mixture represented by the String @c type. if the string
@@ -256,6 +266,9 @@ Mixture stringToMixture( std::string const& type);
  * <tr> <td> "Gaussian_pk_s"      </td><td> "Gaussian_p_s"      </td> </tr>
  * <tr> <td> "Categorical_pk_pjk" </td><td> "Categorical_p_pjk" </td> </tr>
  * <tr> <td> "Categorical_pk_pk"  </td><td> "Categorical_p_pk"  </td> </tr>
+ * <tr> <td> "Poisson_pk_ljk"     </td><td> "Poisson_p_ljk"     </td> </tr>
+ * <tr> <td> "Poisson_pk_lk"      </td><td> "Poisson_p_lk"      </td> </tr>
+ * <tr> <td> "Poisson_pk_ljlk"    </td><td> "Poisson_p_ljlk"    </td> </tr>
  * </table>
  *  @param type the String we want to convert
  *  @param[out] freeProp @c true if the model have free proportions, @c false otherwise.
