@@ -40,6 +40,7 @@
 #include "STK_IMixtureModelBase.h"
 #include "Arrays/include/STK_Array1D.h"
 #include "Arrays/include/STK_Array2D.h"
+
 #ifdef STK_MIXTURE_DEBUG
 #include "Arrays/include/STK_Display.h"
 #endif
@@ -59,11 +60,13 @@ template <class Mixture> struct MixtureTraits;
 
 /**@ingroup Clustering
  * @brief Main interface class for mixture models.
- * At this level we create the array of Components.
+ * At this level we create the array of Parameters.
  *
  * The pseudo virtual methods to implement in derived class are
  * @code
+ * // implementation of this method is required
  * Param getParametersImpl() const;
+ *
  * // default implementation (do nothing) provided to all these methods
  * void initializeModelImpl();
  * bool initializeStepImpl(); // return true by default
@@ -85,44 +88,34 @@ class IMixtureModel : public IRecursiveTemplate<Derived>, public IMixtureModelBa
 
   protected:
     /** Default constructor.
-     *  Set the number of cluster and create the parameters struct.
+     *  @param nbCluster the number of cluster
      **/
-    IMixtureModel( int nbCluster)
-                 : IMixtureModelBase(nbCluster)
-                 , p_dataij_(0)
-                 , components_(nbCluster, 0)
-    {
-      for (int k= components_.begin(); k < components_.end(); ++k)
-      { components_[k] = new Parameters();}
-    }
+    inline IMixtureModel( int nbCluster)
+                        : IMixtureModelBase(nbCluster)
+                        , p_dataij_(0)
+                        , components_(nbCluster)
+    {}
     /** copy constructor.
-     *  Call the clone method of the Parameters class.
-     *  The pointer on the data set is copied as-is. Just check if you should not
+     *  - The pointer on the data set is copied as-is. Check if you should not
      *  change it on the copied object.
+     *  - The Parameter class is copied using the assign operator.
      *  @param model the model to copy
      **/
     IMixtureModel( IMixtureModel const& model)
                  : IMixtureModelBase(model)
                  , p_dataij_(model.p_dataij_)
                  , components_(model.components_)
-    {
-      for (int k= components_.begin(); k < components_.end(); ++k)
-      { components_[k] = model.components_[k]->clone(); }
-    }
+    {}
 
   public:
     /** destructor */
-    ~IMixtureModel()
-    {
-      for (int k= components_.begin(); k < components_.end(); ++k)
-      { delete components_[k];}
-    }
+    inline ~IMixtureModel() {}
     /** create pattern.  */
     inline IMixtureModel* create() const { return new Derived(this->nbCluster());}
     /** @return a pointer on the current data set */
     inline Array const* p_data() const { return p_dataij_;}
     /** @return a constant reference on the k-th parameter */
-    inline Parameters const* p_param(int k) const { return components_[k];}
+    inline Parameters const& param(int k) const { return components_[k];}
     /** Set the data set and initialize the model.
      *  @param data the data set to set*/
     void setData(Array const& data)
@@ -134,7 +127,7 @@ class IMixtureModel : public IRecursiveTemplate<Derived>, public IMixtureModelBa
      *  @param i,k indexes of the sample and of the component
      **/
     inline Real lnComponentProbability(int i, int k)
-    { return components_[k]->computeLnLikelihood(p_dataij_->row(i));}
+    { return components_[k].computeLnLikelihood(p_dataij_->row(i));}
     /** @brief This function will be called once the model is created and data is set.
      *  @note a stk++ mixture create and initialize all the containers when the data
      *  is set. Thus the default behavior is @c return true.
@@ -146,7 +139,7 @@ class IMixtureModel : public IRecursiveTemplate<Derived>, public IMixtureModelBa
     void storeIntermediateResults(int iteration)
     {
       for (int k= components_.begin(); k < components_.end(); ++k)
-      { components_[k]->storeIntermediateResults(iteration); }
+      { components_[k].storeIntermediateResults(iteration); }
       this->asDerived().storeIntermediateResultsImpl(iteration);
     }
     /** Release the stored results. This is usually used if the estimation
@@ -155,8 +148,8 @@ class IMixtureModel : public IRecursiveTemplate<Derived>, public IMixtureModelBa
     void releaseIntermediateResults()
     {
       for (int k= components_.begin(); k < components_.end(); ++k)
-      { components_[k]->releaseIntermediateResults(); }
-      // release shared parameters staticitcs if any
+      { components_[k].releaseIntermediateResults(); }
+      // release shared parameters statistics if any
       this->asDerived().releaseIntermediateResultsImpl();
     }
     /** call specific model finalization stuff */
@@ -165,7 +158,7 @@ class IMixtureModel : public IRecursiveTemplate<Derived>, public IMixtureModelBa
     void setParameters()
     {
       for (int k= components_.begin(); k < components_.end(); ++k)
-      { components_[k]->setParameters(); }
+      { components_[k].setParameters(); }
       // set shared parameters if any
       this->asDerived().setParametersImpl();
     }
@@ -173,6 +166,7 @@ class IMixtureModel : public IRecursiveTemplate<Derived>, public IMixtureModelBa
     Param getParameters() const
     { return this->asDerived().getParametersImpl();}
 
+    // default implementation of the pseudo-virtual methods
     /** default implementation of initializeModelImpl (do nothing) */
     void initializeModelImpl() {}
     /** default implementation of initializeStepImpl (return true) */
@@ -188,7 +182,7 @@ class IMixtureModel : public IRecursiveTemplate<Derived>, public IMixtureModelBa
 
   protected:
     /** @brief Initialize the model before its first use.
-     * This function is used when the data is set.
+     * This function is triggered when the data is set.
      * In this interface, the @c initializeModel() method
      *  - set the number of samples and variables of the mixture model
      *  - resize the parameters of each component with the range of the variables
@@ -205,22 +199,22 @@ class IMixtureModel : public IRecursiveTemplate<Derived>, public IMixtureModelBa
       this->setNbVariable(p_dataij_->sizeCols());
       // initialize the parameters
       for (int k= components_.begin(); k < components_.end(); ++k)
-      { components_[k]->resize(p_dataij_->cols());}
+      { components_[k].resize(p_dataij_->cols());}
       // call specific model initialization stuff
       this->asDerived().initializeModelImpl();
     }
     /** @return the array with the components */
-    inline Array1D<Parameters*> const& components() const { return components_;}
+    inline Array1D<Parameters> const& components() const { return components_;}
     /** @return the array with the components */
-    inline Array1D<Parameters*>& components() { return components_;}
+    inline Array1D<Parameters>& components() { return components_;}
     /** @return a pointer on the k-th parameter */
-    inline Parameters* p_param(int k) { return components_[k];}
+    inline Parameters& param(int k) { return components_[k];}
 
   private:
     /** pointer on the data set */
     Array const* p_dataij_;
     /** Array of the components of the mixture model */
-    Array1D< Parameters* > components_;
+    Array1D< Parameters > components_;
 };
 
 } // namespace STK
