@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------*/
-/*     Copyright (C) 2004-2012  Serge Iovleff
+/*     Copyright (C) 2004-2014  Serge Iovleff
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as
@@ -34,20 +34,30 @@
  **/
 
 #include <cmath>
+
+#ifdef _OPENMP
+#include <omp.h>
+#endif
+
 #ifdef STK_MIXTURE_DEBUG
 #include "Arrays/include/STK_Display.h"
 #endif
+
 #include "../include/STK_IMixtureComposer.h"
 #include "STatistiK/include/STK_Law_Categorical.h"
 #include "STatistiK/include/STK_Stat_Functors.h"
+#include "Arrays/include/STK_Array2DPoint.h" // for sum
 
 namespace STK
 {
-IMixtureComposer::IMixtureComposer( int nbSample, int nbVariable, int nbCluster)
-                                  : IStatModelBase(nbSample, nbVariable)
+IMixtureComposer::IMixtureComposer( int nbSample, int nbCluster)
+                                  : IStatModelBase(nbSample)
                                   , nbCluster_(nbCluster)
-                                  , prop_(nbCluster), tik_(nbSample, nbCluster), tk_(nbCluster), zi_(nbSample)
+                                  , prop_(nbCluster), tik_(nbSample, nbCluster), nk_(nbCluster), zi_(nbSample)
                                   , state_(Clust::modelCreated_)
+#ifndef _OPENMP
+                                  , lnComp_(nbCluster)
+#endif
 { initializeMixtureParameters(); }
 
 /* copy constructor */
@@ -58,6 +68,9 @@ IMixtureComposer::IMixtureComposer( IMixtureComposer const& model)
                                   , tik_(model.tik_)
                                   , zi_(model.zi_)
                                   , state_(model.state_)
+#ifndef _OPENMP
+                                  , lnComp_(model.lnComp_)
+#endif
 {}
 /* destructor */
 IMixtureComposer::~IMixtureComposer() {}
@@ -87,9 +100,9 @@ void IMixtureComposer::randomClassInit()
 #endif
   if (state() < 2) { initializeStep();}
   Law::Categorical law(prop_);
-  for (int i = zi_.begin(); i< zi_.end(); ++i)
-  { zi_.elt(i) = law.rand();}
-  cStep();
+  for (int i = zi_.begin(); i< zi_.end(); ++i) { zi_.elt(i) = law.rand();}
+  if (cStep()<2) throw(Clust::randomClassInitFail_);
+  mStep();
   eStep();
   // model intialized
   setState(Clust::modelParamInitialized_);
@@ -105,7 +118,9 @@ void IMixtureComposer::randomFuzzyInit()
   stk_cout << _T("Entering IMixtureComposer::randomFuzzyInit()\n");
 #endif
   if (state() < 2) { initializeStep();}
-  randomFuzzyTik();
+  if (randomFuzzyTik()<2) throw(Clust::randomFuzzyInitFail_);
+  mapStep();
+  mStep();
   eStep();
   // model intialized
   setState(Clust::modelParamInitialized_);
@@ -121,8 +136,8 @@ int IMixtureComposer::cStep()
   for (int i=tik_.beginRows(); i < tik_.endRows(); i++)
   { tik_.elt(i, zi_[i]) = 1.;}
   // count the number of individuals in each class
-  tk_.move(Stat::sum(tik_));
-  return tk_.minElt();
+  nk_= Stat::sum(tik_);
+  return nk_.minElt();
 }
 
 /* simulate zi  */
@@ -133,37 +148,47 @@ int IMixtureComposer::sStep()
   { zi_.elt(i) = Law::Categorical::rand(tik_.row(i));}
   return cStep();
 }
+
 /* compute tik, default implementation. */
 Real IMixtureComposer::eStep()
 {
-#ifdef STK_MIXTURE_VERY_VERBOSE
+#ifdef STK_MIXTURE_DEBUG
   stk_cout << _T("Entering IMixtureComposer::eStep()\n");
 #endif
-  Real sum = 0.; tk_ =0.;
-  for (int i = tik_.beginRows(); i < tik_.endRows(); ++i)
-  {
-    // get maximal element of ln(x_i,\theta_k) + ln(p_k)
-    Array2DPoint<Real> lnComp(tik_.cols());
-    for (int k=tik_.beginCols(); k< tik_.endCols(); k++)
-    { lnComp[k] = std::log(prop_[k])+lnComponentProbability(i,k);}
-    int kmax;
-    Real max = lnComp.maxElt(kmax);
-    // set zi_
-    zi_[i] = kmax;
-    // compute sum_k p_k exp{lnCom_k - lnComp_kmax}
-    tik_.row(i) = (lnComp - max).exp();
-    Real sum2 = tik_.row(i).sum();
-    tik_.row(i) /= sum2;
-    // count the expected number of individuals in each class
-    tk_ += tik_.row(i);
-    // compute lnLikelihood
-    sum += max + std::log(sum2);
-  }
-  setLnLikelihood(sum);
-#ifdef STK_MIXTURE_VERY_VERBOSE
-  stk_cout << _T("IMixtureComposer::eStep() done\n");
+  Real sum = 0.; nk_ =0.;
+  int i;
+#ifdef _OPENMP
+#pragma omp parallel for reduction (+:sum)
 #endif
-  return tk_.minElt();
+  for (i = tik_.beginRows(); i < tik_.endRows(); ++i) { sum += eStep(i);}
+  // update ln-likelihood
+  setLnLikelihood(sum);
+  // compute proportions
+  nk_ = Stat::sum(tik_);
+#ifdef STK_MIXTURE_DEBUG
+  stk_cout << _T("IMixtureComposer::eStep() done\n");
+  stk_cout << _T("lnLikelihood =") << sum << _T("\n");
+#endif
+  return nk_.minElt();
+}
+
+/* compute tik, default implementation. */
+Real IMixtureComposer::eStep(int i)
+{
+#ifdef _OPENMP
+  CPointX lnComp_(tik_.sizeCols());
+#endif
+  // get maximal element of ln(x_i,\theta_k) + ln(p_k)
+  for (int k=baseIdx; k< tik_.endCols(); k++)
+  { lnComp_[k] = std::log(prop_[k])+lnComponentProbability(i,k);}
+  int kmax;
+  Real max = lnComp_.maxElt(kmax);
+  // set zi_
+  zi_[i] = kmax;
+  // return  max + sum_k p_k exp{lnCom_k - lnComp_kmax}
+  Real sum =  (tik_.row(i) = (lnComp_ - max).exp()).sum();
+  tik_.row(i) /= sum;
+  return max + std::log( sum );
 }
 
 /* @return the computed likelihood of the i-th sample.
@@ -172,12 +197,11 @@ Real IMixtureComposer::eStep()
 Real IMixtureComposer::computeLnLikelihood(int i) const
 {
   // get maximal value
-  CArrayPoint<Real> lnComp(prop_.size());
+  CPointX lnComp(prop_.size());
   for (int k = prop_.begin(); k< prop_.end(); ++k)
   { lnComp[k] = std::log(prop_[k]) + lnComponentProbability(i, k);}
-  int kmax;
-  Real lnCompMax = lnComp.maxElt(kmax);
   // compute result
+  Real lnCompMax = lnComp.maxElt();
   return std::log((lnComp-lnCompMax).exp().sum())+lnCompMax;
 }
 
@@ -219,7 +243,7 @@ void IMixtureComposer::mapStep()
   {
     int k;
     tik_.row(i).maxElt(k);
-    zi_.elt(i) = k;
+    zi_[i] = k;
   }
 }
 
@@ -228,24 +252,25 @@ void IMixtureComposer::initializeMixtureParameters()
 {
   prop_ = 1./nbCluster_;
   tik_  = 1./nbCluster_;
-  tk_   = Real(nbSample())/nbCluster_;
+  nk_   = Real(nbSample())/nbCluster_;
   zi_   = baseIdx;
 }
 
 /* generate random tik_ */
-void IMixtureComposer::randomFuzzyTik()
+int IMixtureComposer::randomFuzzyTik()
 {
   RandBase generator;
-  tk_ = 0.;
+  nk_ = 0.;
+  tik_.randUnif();
   for (int i = tik_.beginRows(); i < tik_.endRows(); ++i)
   {
     // create a reference on the i-th row
-    Array2DPoint<Real> tikRowi(tik_.row(i), true);
-    generator.randUnif(tikRowi);
+    CPointX tikRowi(tik_.row(i), true);
     tikRowi = tikRowi * prop_;
     tikRowi /= tikRowi.sum();
-    tk_ += tikRowi;
+    nk_ += tikRowi;
   }
+  return nk_.minElt();
 }
 
 } // namespace STK
